@@ -40,12 +40,11 @@ use Moo;
 use namespace::clean;
 use Module::Pluggable;
 
-our $VERSION = '0.110'; # VERSION
+our $VERSION = '0.111'; # VERSION
 
-has joiner => (
+has joiners => (
     is => 'rw',
-    isa => sub { die "Not a string\n" if (ref $_[0]); },
-    default => sub { ':' },
+    default => sub { [ ':', '.' ] },
 );
 has cidr => (
     is => 'rw',
@@ -138,7 +137,7 @@ sub run {
 
     if ($overlaps) {
         for my $return (@{$identifier->tree_overlaps}) {
-            my @r = map { join $identifier->joiner, $_->payload->entity, $_->payload->ip; } @{$return};
+            my @r = map { $identifier->join($_->payload->entity, $_->payload->ip); } @{$return};
             warn join(' => ', @r), "\n";
         }
     }
@@ -297,7 +296,7 @@ sub identify {
     }
 
     if ($self->cidr) {
-        my @e = map { join ( $self->joiner, $_->entity, $_->ip) } @return;
+        my @e = map { $self->join($_->entity, $_->ip) } @return;
         return join ' => ', @e;
     }
     my $r = join (' => ', map {
@@ -306,6 +305,18 @@ sub identify {
     return $r;
 }
 
+sub join {
+    my ($self, @parts) = @_;
+
+    my $joiners = $self->joiners;
+    my $joiner = $joiners->[0];   # assume IPv4
+    if (grep { $_->can('version') and $_->version eq '6' } @parts) {
+        $joiner = $joiners->[1];  # use the IPv6 string
+    }
+    $joiner = ':' if (not defined $joiner);    # if all else fails...
+    return join $joiner, @parts;
+}
+
 sub tree_overlaps {
     my ($self) = @_;
 
@@ -352,7 +363,7 @@ Net::IP::Identifier - Identify IPs that fall within collections of network block
 
 =head1 VERSION
 
-version 0.110
+version 0.111
 
 =head1 SYNOPSIS
 
@@ -416,10 +427,11 @@ A format modifier.  See B<identify> below.
 
 A format modifier.  See B<identify> below.
 
-=item joiner => string
+=item joiners => ( [ IPv4_string, IPv6_string ] )
 
-The string to use when 'join'ing pieces.  The default is to use ':' on IPv4
-addresses and '.' on  IPv6 addresses.
+Returns a reference to an array of two strings to use when 'join'ing
+pieces.  The default is [ ':', '.' ] which uses ':' on IPv4 addresses and
+'.' on  IPv6 addresses.
 
 =back
 
@@ -476,6 +488,12 @@ Flags may be used concurrently.
 In scalar context, a string is return where the pieces are joined using
 B<joiner>.  In array context, the array of pieces is returned.
 
+=item join ( @parts )
+
+Gets the B<joiners>, then scans B<@parts> looking for objects which I<can> identify
+themselves as IPv4 vs. IPv6.  Uses the appropriate element of B<joiners>, and returns
+a 'join'ed string.
+
 =item tree_overlaps
 
 During construction of the binary tree, there may be netblocks that overlap
@@ -499,15 +517,14 @@ Plugins uploaded to CPAN should be well known entities, or entities with
 wide netblocks.  Let's not congest CPAN with a multitude of class C
 netblocks.
 
-Entities with child netblocks can name them in a B<children> subroutine
-(see Microsoft and Hotmail for example).  If you want to add a netblock as a
-child, you'll need to arrange with the parent's CPAN owner to add it.  This
-relationship is independant of the network hierarchy, and is currently ignored
-by Net::IP::Identifier.
+Entities with child netblocks can name them in a B<children> subroutine.
+If you want to add a netblock as a child, you'll need to arrange with the
+parent's CPAN owner to add it.  This relationship is independant of the
+network hierarchy, and is currently ignored by Net::IP::Identifier.
 
 Plugins must satisfy the Net::IP::Identifier_Role (see Role::Tiny).
-Supplying the entity name and setting the list if netblocks in the B<new>
-method is sufficient.  See the existing Plugins for examples.
+Supplying the entity name and setting the list of netblocks in B<ips> in
+the B<new> method is sufficient.  See the existing Plugins for examples.
 
 Test your plugin by running B<Identifier.pm> with the C<overlaps> flag.
 C<overlaps> causes overlapping netblocks to be reported.  Overlaps are not
