@@ -17,11 +17,9 @@ use parent 'Net::IP';
 use Math::BigInt;
 use Carp;
 
-our $VERSION = '0.110'; # VERSION
+our $VERSION = '0.111'; # VERSION
 
-use overload (
-    '""' => 'print',
-);
+use overload '""' => \&print;
 
 # Accept any of:
 #   Net::IP::Identifier::Net object or class
@@ -202,7 +200,7 @@ Net::IP::Identifier::Net - subclass Net::IP to add some functionality
 
 =head1 VERSION
 
-version 0.110
+version 0.111
 
 =head1 SYNOPSIS
 
