@@ -1,6 +1,6 @@
 #===============================================================================
 #      PODNAME:  Net::IP::Identifier::Plugin::Hotmail
-#     ABSTRACT:  identify Hotmail owned IP addresses
+#     ABSTRACT:  identify Hotmail owned IP addresses - obsolete
 #
 #       AUTHOR:  Reid Augustin (REID)
 #        EMAIL:  reid@hellosix.com
@@ -10,15 +10,13 @@
 use 5.008;
 use strict;
 use warnings;
-#
-# _ENTITY_REGEX_ hotmail|microsoft
 
 package Net::IP::Identifier::Plugin::Hotmail;
 
 use Role::Tiny::With;
 with qw( Net::IP::Identifier_Role );
 
-our $VERSION = '0.110'; # VERSION
+our $VERSION = '0.111'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -26,15 +24,9 @@ sub new {
     my $self = {};
     bless $self, (ref $class || $class);
 
-    # List of known Hotmail IP blocks as of May 2015
+    # as of May 2015, all netblocks previously owned by Hotmail are
+    #    now owned directly by Microsoft - this module is obsolete
     $self->ips(
-        '64.4.0.0/18',
-        '65.52.0.0/14',
-        # extending 157.54.0.0/15 to include 157.56.0.0/14
-        # extending 157.54.0.0-157.59.255.255 to include 157.60.0.0/16
-        '157.54.0.0-157.60.255.255',
-        '207.46.0.0/16',
-        # 4 Network Blocks
     );
     return $self;
 }
@@ -53,29 +45,20 @@ __END__
 
 =head1 NAME
 
-Net::IP::Identifier::Plugin::Hotmail - identify Hotmail owned IP addresses
+Net::IP::Identifier::Plugin::Hotmail - identify Hotmail owned IP addresses - obsolete
 
 =head1 VERSION
 
-version 0.110
+version 0.111
 
 =head1 SYNOPSIS
 
- use Net::IP::Identifier::Plugin::Hotmail;
+ # OBSOLETE use Net::IP::Identifier::Plugin::Hotmail;
 
 =head1 DESCRIPTION
 
-Net::IP::Identifier::Plugin::Hotmail identifies Hotmail host IPs.
-
-=head2 Methods
-
-=over
-
-=item new
-
-Creates a new Net::IP::Identifier::Plugin::Hotmail object.
-
-=back
+This module is obsolete.  All netblocks previously known to be owned by
+Hotmail are now owned by Microsoft (as of May 2015).
 
 =head1 SEE ALSO
 
