@@ -17,13 +17,11 @@ use Role::Tiny;
 use Net::IP;
 use Net::IP::Identifier::Net;
 
-our $VERSION = '0.110'; # VERSION
+our $VERSION = '0.111'; # VERSION
 
 requires qw( new name );
 
-use overload (
-    '""' => 'name',
-);
+use overload '""' => sub { shift->name };
 
 sub ips {
     my ($self, @new) = @_;
@@ -116,7 +114,7 @@ Net::IP::Identifier_Role - The role that Net::IP::Identifier plugins must satisf
 
 =head1 VERSION
 
-version 0.110
+version 0.111
 
 =head1 SYNOPSIS
 
